@@ -98,7 +98,9 @@ class CodeGuruReviewerClient(BaseClient):
         KMSKeyDetails: KMSKeyDetailsTypeDef = ...
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        .
+        Use to associate an Amazon Web Services CodeCommit repository or a repository
+        managed by Amazon Web Services CodeStar Connections with Amazon CodeGuru
+        Reviewer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#associate_repository)
@@ -129,7 +131,9 @@ class CodeGuruReviewerClient(BaseClient):
         ClientRequestToken: str = ...
     ) -> CreateCodeReviewResponseTypeDef:
         """
-        .
+        Use to create a code review with a
+        [CodeReviewType](https://docs.aws.amazon.com/codeguru/latest/reviewer-
+        api/API_CodeReviewType.html)_ of `RepositoryAnalysis`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#create_code_review)
@@ -137,7 +141,7 @@ class CodeGuruReviewerClient(BaseClient):
 
     def describe_code_review(self, *, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        .
+        Returns the metadata associated with the code review along with its status.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#describe_code_review)
@@ -147,7 +151,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, *, CodeReviewArn: str, RecommendationId: str, UserId: str = ...
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        .
+        Describes the customer feedback for a CodeGuru Reviewer recommendation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#describe_recommendation_feedback)
@@ -157,7 +161,10 @@ class CodeGuruReviewerClient(BaseClient):
         self, *, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        .
+        Returns a
+        [RepositoryAssociation](https://docs.aws.amazon.com/codeguru/latest/reviewer-
+        api/API_RepositoryAssociation.html)_ object that contains information about the
+        requested repository association.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#describe_repository_association)
@@ -167,7 +174,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, *, AssociationArn: str
     ) -> DisassociateRepositoryResponseTypeDef:
         """
-        .
+        Removes the association between Amazon CodeGuru Reviewer and a repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#disassociate_repository)
@@ -198,7 +205,7 @@ class CodeGuruReviewerClient(BaseClient):
         NextToken: str = ...
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        .
+        Lists all the code reviews that the customer has created in the past 90 days.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#list_code_reviews)
@@ -214,7 +221,10 @@ class CodeGuruReviewerClient(BaseClient):
         RecommendationIds: Sequence[str] = ...
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        .
+        Returns a list of
+        [RecommendationFeedbackSummary](https://docs.aws.amazon.com/codeguru/latest/reviewer-
+        api/API_RecommendationFeedbackSummary.html)_ objects that contain customer
+        recommendation feedback for all CodeGuru Reviewer users.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#list_recommendation_feedback)
@@ -224,7 +234,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, *, CodeReviewArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListRecommendationsResponseTypeDef:
         """
-        .
+        Returns the list of all recommendations for a completed code review.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#list_recommendations)
@@ -241,7 +251,10 @@ class CodeGuruReviewerClient(BaseClient):
         NextToken: str = ...
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        .
+        Returns a list of
+        [RepositoryAssociationSummary](https://docs.aws.amazon.com/codeguru/latest/reviewer-
+        api/API_RepositoryAssociationSummary.html)_ objects that contain summary
+        information about a repository association.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#list_repository_associations)
@@ -249,7 +262,7 @@ class CodeGuruReviewerClient(BaseClient):
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        .
+        Returns the list of tags associated with an associated repository resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#list_tags_for_resource)
@@ -259,7 +272,7 @@ class CodeGuruReviewerClient(BaseClient):
         self, *, CodeReviewArn: str, RecommendationId: str, Reactions: Sequence[ReactionType]
     ) -> Dict[str, Any]:
         """
-        .
+        Stores customer feedback for a CodeGuru Reviewer recommendation.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#put_recommendation_feedback)
@@ -267,7 +280,7 @@ class CodeGuruReviewerClient(BaseClient):
 
     def tag_resource(self, *, resourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
-        .
+        Adds one or more tags to an associated repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#tag_resource)
@@ -275,7 +288,7 @@ class CodeGuruReviewerClient(BaseClient):
 
     def untag_resource(self, *, resourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
-        .
+        Removes a tag from an associated repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/client/#untag_resource)
